"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Resources = exports.Actions = void 0;
const Reconfig = require('reconfig');
const resourcesConfig = new Reconfig({
    namespace: 'admin-user-module',
    templates: {
        adminUsers: '/{{ namespace }}/adminUser/[userId]',
        adminRoles: '/{{ namespace }}/adminRole/[roleId]',
        adminPolicies: '/{{ namespace }}/adminPolicy/[policyId]',
    },
}, {
    paramsInterpolation: ['[', ']'],
    envPrefix: 'MOONLIGHT_RESOURCES',
});
exports.Actions = {
    AdminUsers: {
        FullAccess: 'admin-user-module:users:*',
        ReadUser: 'admin-user-module:users:read',
        CreateUser: 'admin-user-module:users:create',
        UpdateUser: 'admin-user-module:users:update',
        ResetPassword: 'admin-user-module:users:reset-password',
        DeleteUser: 'admin-user-module:users:delete',
    },
    AdminRoles: {
        FullAccess: 'admin-user-module:roles:*',
        ReadRole: 'admin-user-module:roles:read',
        CreateRole: 'admin-user-module:roles:create',
        UpdateRole: 'admin-user-module:roles:update',
        DeleteRole: 'admin-user-module:roles:delete',
    },
    AdminPolicies: {
        FullAccess: 'admin-user-module:policies:*',
        CreatePolicy: 'admin-user-module:policies:create',
        UpdatePolicy: 'admin-user-module:policies:update',
        ReadPolicy: 'admin-user-module:policies:read',
        DeletePolicy: 'admin-user-module:policies:delete',
    },
};
function getResource(type, data = {}) {
    const template = resourcesConfig.get(`templates.${type}`);
    const params = template
        .match(/[^[\]]+(?=])/g)
        .reduce((prev, match) => {
        const name = match.replace(/[[]]/g, '');
        return Object.assign(prev, { [name]: data[name] || '*' });
    }, {});
    return resourcesConfig.get(`templates.${type}`, params);
}
const adminUsers = getResource.bind(null, 'adminUsers');
const adminRoles = getResource.bind(null, 'adminRoles');
const adminPolicies = getResource.bind(null, 'adminPolicies');
exports.Resources = {
    adminUsers,
    adminPolicies,
    adminRoles,
};
//# sourceMappingURL=auth.js.map